<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Carrito extends CI_Controller{

    public function __construct()
    {        
        parent::__construct();
        $this->load->model('productsmodel');
        $this->load->model('cartmodel');
        $this->load->library('cart');
        $this->load->model('statusmodel');
        $this->load->model('ordersmodel');
        $this->load->model('usersmodel');
        $this->load->model('metodosmodelo');
        $this->statusmodel->checkUser();
        

        //$this->session->sess_destroy();

        //var_dump($this->cart->contents());

        //var_dump($this->session->all_userdata());
    }

    /*
        
    Primer paso del carro
    Muestro los productos del carrito

    */

    public function index()
    {

        $head = array(

            'title'         => 'Tu carrito de compras | ' .$this->config->item('site_name'), 
            'description'   => false,            
        );

        $this->templates->head($head);
        $this->templates->header();

        $data = array(

            'cart_data'     => $this->functions->checkCartData(),
            'cart'          => false,
            'breadcrumb'    => $this->functions->carritoBreadcrumb('Mis productos'),

        );        

        if( $this->cart->total_items() > 0 )
        {
            $cart = array();

            foreach ($this->cart->contents() as $key => $items)
            {

                $cart[$key] = new stdClass();

                $cart[$key] = $this->productsmodel->single($items['id']);

                if($cart[$key])
                {
                    $cart[$key]->items  = $items;
                }
                else
                {
                    unset($cart[$key]);
                }
                
            }

            $data['cart'] = $cart;

            $this->load->view('site/carrito/carrito', $data);
        }
        else
        {
            $this->load->view('site/carrito/carrito_vacio', $data);
        }

        $this->templates->footer();
    }

    /*
        
    Segundo paso del carro
    Muestros datos y pido info de envio, sino pido que se registre

    */

    public function datos()
    {

        if( !$this->statusmodel->checkUser() ) show_404();

        if( $this->form_validation->run('facturacion') )
        {
            $this->eliminar_datos_carrito();

            $array = array();

            foreach( $this->input->post() as $key => $post )
            {
                $array['CARRITO_'.$key] = $post;
            }

            $this->session->set_userdata($array);

            redirect('carrito/confirmacion');
        }


        $user = $this->usersmodel->single( $this->session->userdata('id_user') );

        //if(!$user) exit();

        $head = array(

            'title'         => 'Datos de compra | ' .$this->config->item('site_name'), 
            'description'   => false,            
        );

        $this->templates->head($head);
        $this->templates->header();

        $data = array(

            'breadcrumb'    => $this->functions->carritoBreadcrumb('Datos de facturacion'),
            'user'          => $user,
            'metodos'       => $this->metodosmodelo->get(0, 990000, "nombre DESC", true)

        );

        $this->load->view('site/carrito/datos', $data);

        $this->templates->footer();
    }

    /*
        
    Pagina de confirmacion de pago

    */


    public function confirmacion()
    {
        $this->checkAutorizado('carrito/confirmacion');

        $head = array(

            'title'         => 'Datos de compra | ' .$this->config->item('site_name'), 
            'description'   => false,            
        );

        $this->templates->head($head);
        $this->templates->header();

        $cart = array();

        foreach ($this->cart->contents() as $key => $items)
        {
            $cart[$key] = new stdClass();
            $cart[$key] = $this->productsmodel->single($items['id']);
            $cart[$key]->items  = $items;
        }

        $data = array(

            'breadcrumb'    => $this->functions->carritoBreadcrumb('Datos de facturacion'),
            'cart'          => $cart,

        );

        $this->load->view('site/carrito/confirmacion', $data);

        $this->templates->footer();
    }


    /*
        
    Pagina de proceso de compra

    */

    public function procesar()
    {
        
        $this->checkAutorizado('carrito/confirmacion');

        // Aca ingreso el pedido
        if( !$this->ingresarPedido() ) redirect('carrito/error');

        //Envio mails
        $this->notificar();

        // Reseteo el carrito
        $this->eliminar_datos_carrito();

        $this->cart->destroy();

        $head = array(

            'title'         => 'Compra realizada con éxito | ' .$this->config->item('site_name'), 
            'description'   => false,            
        );

        $this->templates->head($head);
        $this->templates->header();

        $this->load->view('site/carrito/exito');

        $this->templates->footer();
    }


    public function error()
    {
        
        $user = $this->usersmodel->single( $this->session->userdata('id_user') );

        if(!$user) exit();

        $head = array(

            'title'         => 'Error | ' .$this->config->item('site_name'), 
            'description'   => false,            
        );

        $this->templates->head($head);
        $this->templates->header();

        $data = array(

            'user'          => $user,

        );

        $this->load->view('site/carrito/error', $data);

        $this->templates->footer();
    }


    /*
    Metodo para indicar que el usuario no esta autoriazo a acceder al contenido
    */

    public function autorizacion()
    {
        if($this->statusmodel->checkUser()) redirect('carrito');

        $head = array(

            'title'         => 'Acceso no autorizado | ' .$this->config->item('site_name'), 
            'description'   => false,            
        );

        $this->templates->head($head);
        $this->templates->header();

        $this->load->view('site/carrito/autorizacion');

        $this->templates->footer();
    }

    /*
    Metodo para ingresar el pedido en la base de datos
    */
    private function ingresarPedido()
    {

        $info   = 'Tipo de documento : ' . $this->session->CARRITO_tipo_documento."\n";
        $info  .= 'Documento : ' . $this->session->CARRITO_documento."\n";
        $info  .= 'Teléfono : ' . $this->session->CARRITO_telefono."\n";

        if( $this->session->has_userdata('CARRITO_factura') )
        {
            $info  .= 'El cliente solicita factura con RUT'."\n";
            $info  .= 'Razón social : ' . $this->session->CARRITO_razon_social."\n";
            $info  .= 'RUT : ' . $this->session->CARRITO_rut."\n";
        }

        $info  .= 'Departamento : ' . $this->session->CARRITO_departamento."\n";
        //$info  .= 'Ciudad : ' . $this->session->CARRITO_ciudad."\n";
        $info  .= 'Código postal : ' . $this->session->CARRITO_codigo_postal."\n";
        $info  .= 'Dirección : ' . $this->session->CARRITO_direccion."\n";
        $info  .= 'Aclaraciones : ' . $this->session->CARRITO_aclaraciones."\n";
        

        $pedido = array(

            'id'                        => null,
            'user'                      => $this->session->userdata('id_user'),
            'date'                      => date('Y-m-d H:i:s'),
            'info'                      => $info,
            'total'                     => $this->functions->total()->total,
            'costo_envio'               => $this->functions->totalEnvio()->total,
            'currency'                  => 'UYU',
            'status'                    => 'pendiente',

        );

        if( $this->ordersmodel->add($pedido) )
        {   
            $id = $this->ordersmodel->last();

            $this->ordersmodel->addOrderProducts($id);

            return true;
        }

        return false;
    }

    public function prueba()
    {
      

        $body_empresa = $this->load->view('emails/carrito-empresa', false, true);

        $email_empresa = array(

            'titulo'    => 'Compra vía web',    
            'html'      => $body_empresa,

        );

        echo $html_empresa = $this->load->view('email', $email_empresa, true);
    }

    /*
    Metodo para notificar a la empresa y al usuario
    */
    public function notificar()
    {
        /*Mail al cliente*/
        $body_cliente = $this->load->view('emails/carrito-cliente', false, true);

        $email_cliente = array(

            'titulo'    => 'Solicitud de presupuesto',    
            'html'      => $body_cliente,

        );

        $html_cliente = $this->load->view('email', $email_cliente, true);

        $data = array(

            'to'            => $this->session->mail_user,
            'reply_to'      => $this->config->item('smtp_user'),
            'subject'       => 'Solicitud de presupuesto ' . $this->config->item('site_name'),
            'html'          => $html_cliente
        );

        $this->functions->sendEmail($data);

        $d['user'] = $this->usersmodel->single( $this->session->userdata('id_user') );

        /*Mail a la empresa*/
        $body_empresa = $this->load->view('emails/carrito-empresa', $d, true);

        $email_empresa = array(

            'titulo'    => 'Solicitud de presupuesto',    
            'html'      => $body_empresa,

        );

        $html_empresa = $this->load->view('email', $email_empresa, true);

        $data = array(

            'to'            => $this->config->item('email_to'),
            'reply_to'      => $this->config->item('email_to'),
            'subject'       => 'Solicitud de presupuesto ' . $this->config->item('site_name'),
            'html'          => $html_empresa
        );

        $this->functions->sendEmail($data);
    }


    public function presupuesto()
    {
        $this->procesar();
    }


    /*----------------------------------------------------*/

    public function add()
    {
        $json = new stdClass();
        $json->success = false;
        $json->products = $this->cart->total_items();

        if(isset($_POST['id']))
        {
            //ahora chequeo que exista
            $product    = $this->productsmodel->single( intval( $this->input->post('id') ) );

            if($product != false && $product->cart->active )
            {
                //levanto todos los datos del producto
                
                $price      = $product->cart->price;

                $factor     = $product->cart->discount / 100;

                $descuento  = $price * $factor;

                $final = round( $price - $descuento );

                $qty        = $this->input->post('qty');

                if($qty == '')
                {
                    $qty = 1;
                }

                $data = array(

                    'id'        => $this->input->post('id'),
                    'qty'       => $qty,
                    'price'     => $final,
                    'name'      => htmlentities( trim($product->name), ENT_COMPAT, "UTF-8"),
                    'currency'  => $product->cart->currency,
                    'discount'  => $product->cart->discount,
                    'code'      => $product->code,

                );
                
                //si llego aca, agrego al carrito
                $this->cart->product_name_rules = '[:print:]';

                if($this->cart->insert($data))
                {
                    $json->success  = true;
                    $json->products = $this->cart->total_items();
                }

            }
            
            
        }

        echo json_encode($json);
    }

    public function update()
    {
        $response = new stdClass();
        $response->success = false;
        $response->object = false;

        $data = array(

            'rowid'     => $_POST['rowid'],
        );

        if( isset($_POST['qty']) )
        {
            $data['qty'] = $_POST['qty'];
        }

        
        if( $this->cart->update($data) )
        {
            $response->success      = true;
            $response->object       = $this->cart->get_item( $_POST['rowid'] );
            $response->price        = $this->functions->precioCart($response->object);
            $response->total_pes    = $this->functions->total('PES');
            $response->total_dola   = $this->functions->total('DOL');
        }
        
        echo json_encode($response);
    }

    public function vaciar()
    {
        $this->cart->destroy();

        if( $this->input->server('HTTP_REFERER') )
        {
            redirect( $this->input->server('HTTP_REFERER') );
        }
        else
        {
            redirect('productos');
        }
    }

    public function delete($rowid)
    {
        $array = array(

            'rowid'         => $rowid,
            'qty'           => 0
        );

        $this->cart->update($array);

        redirect('carrito');
    }

    private function eliminar_datos_carrito()
    {
        foreach($this->session->all_userdata() as $key => $value)
        {
            if( strpos($key, 'CARRITO_') !== false )
            {
                $this->session->unset_userdata($key);
            }
            
        }
    }

    private function checkAutorizado($url)
    {
        if( !$this->statusmodel->checkUser() )
        {
            $this->session->set_userdata('REDIRECCION_LOGIN', $url );

            redirect('carrito/autorizacion');
        }
        elseif( !$this->cart->total_items() )
        {
            redirect('carrito');
        }
        else
        {
            return true;
        }
    }

}
