<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Users extends CI_Controller{

    private $tipo = "usuarios";
    private $resultados     = 100;

    public function __construct()
    {
        parent::__construct();

        $this->load->model('settingsmodel');
        $this->load->model('statusmodel');
        $this->load->model('usersmodel');
        $this->session->set_userdata('admin_menu', 'users');
        
        if( ! $this->statusmodel->loggedAdmin())
        {
            redirect('admin');
            exit();
        }
    }

    private function download_send_headers($filename)
    {
        $now = gmdate("D, d M Y H:i:s");
        header("Expires: Tue, 03 Jul 2001 06:00:00 GMT");
        header("Cache-Control: max-age=0, no-cache, must-revalidate, proxy-revalidate");
        header("Last-Modified: {$now} GMT");

        // force download  
        //header("Content-Type: application/force-download");
       // header("Content-Type: application/octet-stream");
       // header("Content-Type: application/download");

        // disposition / encoding on response body
        header("Content-Disposition: attachment;filename={$filename}");
        header("Content-Transfer-Encoding: binary");
    }

    private function array2csv($array)
    {

        if (count($array) == 0)
        {
             return null;
        }
       
        ob_start();
        
        $df = fopen("./csv/lista_".date("Y-m-d-H:i:s").".csv", 'w');
       
        fputcsv($df, array_keys(reset($array)));
        
        foreach ($array as $row)
        {
            fputcsv($df, $row);
        }
        
        fclose($df);
       
        return ob_get_clean();

    }

    public function exportar_csv()
    {
        
        // output headers so that the file is downloaded rather than displayed
        header('Content-Type: text/csv; charset=utf-8');
        header('Content-Disposition: attachment; filename=usuarios_'.$this->config->item('site_name').'_'.date('Y-m-d_H:i:s').'.csv');

        // create a file pointer connected to the output stream
        $output = fopen('php://output', 'w');

        // output the column headings
        fputcsv($output, array('Nombre', 'Mail', 'Telefono'), ';');

        $usuarios = $this->usersmodel->get(false, 0, 9999999);

        if($usuarios != false)
        {
            foreach ($usuarios as $key => $usuario)
            {
                $data = array( ($usuario->lastname . ', ' . $usuario->name) , $usuario->mail, $usuario->tel);

                fputcsv($output, $data, ';');
            }
        }
        
    }

    public function listar($inicio = 0)
    {
        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Lista de usuarios'));
        $this->templates_admin->sidebar();
        $this->templates_admin->subMenu(array('nuevo usuario+' => 'usuarios/nuevo'), false, true, 'usuarios');        

        $data['msj'] = "";
        $confirmar = false;


        $config = array(

            'base_url'      => base_url('admin/usuarios/listar'),
            'total_rows'    => $this->usersmodel->count(),
            'per_page'      => $this->resultados,
            'uri_segment'   => 4,
            'full_tag_open' => '<div class="paginador">',
            'full_tag_close'=> '</div>'

            );

        $this->load->library('pagination');

        $this->pagination->initialize($config);

        $data[$this->tipo]  = $this->usersmodel->get(false, $inicio, $this->resultados);
        $data['tipo']       = $this->tipo;
        $data['paginador']  = $this->pagination->create_links();

        $this->load->view('admin/'.$this->tipo.'/list', $data);
        $this->templates_admin->footer();
    }

    public function nuevo()
    {
        
        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Nuevo Slide'));
        $data = array(  

            'tipo'          => $this->tipo,
            'error'         => "",
            'msj'           => "",
            'added'         => false
        );
        
        if(isset($_POST["enviar"]))
        {

            if($this->form_validation->run('register'))
            {

                $data = array(

                    'id'            => null,
                    'name'          => $this->input->post('name'),
                    'lastname'      => $this->input->post('lastname'),
                    'mail'          => $this->input->post('mail'),
                    'address'       => $this->input->post('address'),
                    'tel'           => $this->input->post('tel'),
                    'pass'          => md5($this->input->post('password')),
                    'active'        => 1
                );

                if( $this->usersmodel->add($data) )
                {
                    $data['added'] = true;
                }
                else
                {
                    $data['msj']    = "Error al crear el usuario";
                }

            }
        }

        $accion = $data['added'] ? 'volver' : 'cancelar';

        $this->templates_admin->sidebar();
        $this->templates_admin->subMenu(array($accion => 'usuarios/listar' ));

        $this->load->view('admin/'.$this->tipo.'/nuevo', $data); 
            
        $this->templates_admin->footer();
    }

    public function editar($id)
    {

        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Nuevo Slide'));
        $data['msj']        = "";
        $data['error']      = "";
        $data['tipo']       = $this->tipo;

        $data['user']     = $this->usersmodel->single($id);

        if(isset($_POST["enviar"]))
        {

            if($this->form_validation->run('data'))
            {

                $data = array(

                    'name'          => $this->input->post('name', true),
                    'lastname'      => $this->input->post('lastname', true),
                    'mail'          => $this->input->post('mail', true),
                    'address'       => $this->input->post('address', true),
                    'tel'           => $this->input->post('tel', true),
                    'pass'          => ($this->input->post('password') != '' ? md5($this->input->post('password', true) ) : $data['user']->pass)
                );

                if( $this->usersmodel->update($id, $data) )
                {
                    redirect('admin/'.$this->tipo.'/listar');
                }

            }        
        }        

        $this->templates_admin->sidebar();
        $this->templates_admin->subMenu(array('cancelar' => 'usuarios/listar' ));

        $this->load->view('admin/'.$this->tipo.'/edit', $data); 
            
        $this->templates_admin->footer();
    }

    public function eliminar_foto($id = false)
    {

        if($id != false)
        {
            $slider = $this->slidermodel->single($id);

            if(file_exists('./pics/'.$this->tipo.'/'.$id.'/01.'.$slider->extension))
            {
                unlink('./pics/'.$this->tipo.'/'.$id.'/01.'.$slider->extension);
            }

            if(file_exists('./pics/'.$this->tipo.'/'.$id.'/02.'.$slider->extension))
            {
                unlink('./pics/'.$this->tipo.'/'.$id.'/02.'.$slider->extension);
            }

            redirect('admin/'.$this->tipo.'/editar/'.$id);

        }
        else
        {
            redirect(base_url());
        }
    }

   

    

    private function update($id)
    {
        $slider = $this->slidermodel->single($id);

        $array = array(

            'title'     => $this->input->post('title'),
            'text'      => $this->input->post('text'),
            'link'      => $this->input->post('link'),
            'order'     => $slider->order,
            'active'    => $slider->active
        );

        if($this->slidermodel->update($slider->id, $array))
        {

            if(isset($_FILES['userfile']))
            {
                if($_FILES['userfile']['name'] != '')
                {

                    if(copy('./pics/'.$this->tipo.'/temp.'.$slider->extension, './pics/'.$this->tipo.'/'.$id.'/temp.'.$slider->extension))
                    {
                        rename('./pics/'.$this->tipo.'/'.$id.'/temp.'.$slider->extension,'./pics/'.$this->tipo.'/'.$id.'/01.'.$slider->extension);
                        copy('./pics/'.$this->tipo.'/'.$id.'/01.'.$slider->extension, './pics/'.$this->tipo.'/'.$id.'/02.'.$slider->extension);
                        unlink('./pics/'.$this->tipo.'/temp.'.$slider->extension);
                        return true;
                    }
                }
                return true;

            }
            return true;
        }

        return false;
    }

    /////////////////////////////////////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////SECCION DE FUNCIONES//////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////////////////////////////


      

    
    
    public function eliminar($id = null){
        
        if($id == false || !is_numeric($id)){

            redirect('admin/paginas/listar');
            exit();
        }
        
        $data['permisos']   = $this->permisos;
        $data['error']      = false;
        $data['titulo']     = ' | <span>Eliminar Pagina</span>';
        $this->load->view('admin/header',$data);

        $menu = array(
            'crear' => false,
            'paginador' => false,
            'cancelar' => false,
            'ordenar' => false
            );

        $this->load->view('admin/paginas/menu',$menu);
        
        //elimino el producto
        if($id != null){
            
            if($this->productosmodelo->eliminar_producto($id)){
                
                $this->load->view('admin/paginas/eliminar_exito');
            
            }else{
                
            }
            
        }else{
            
            show_404();
        }

        //cargo footer
        $this->load->view('admin/footer.php');
    }


    














}
?>